@@ -10,18 +10,22 @@ M = scale(M[index,])/sqrt(ncol(M))   # Subset and scale markers
 G = tcrossprod(M)                    # Genomic relationship matrix
 y = as.vector(scale(Y[index,"E1"])) # Subset response variable
 
-# Calculate heritability using all data
+# Calculate variance components ratio using all data
 fm1 = fitBLUP(y,K=G)
+theta = fm1$varE/fm1$varU
 h2 = fm1$varU/(fm1$varU + fm1$varE)
 
 # Sparse selection index
+fm2 = SSI(y,K=G,theta=theta,nLambda=50)
+
+# The same but passing the heritability instead of theta
 fm2 = SSI(y,K=G,h2=h2,nLambda=50)
 yHat = fitted(fm2)
 
 plot(fm2)  # Penalization vs accuracy
 
 # Equivalence of the SSI with lambda=0 with G-BLUP
-fm3 = SSI(y,K=G,h2=h2,lambda=0,tol=1E-5)
+fm3 = SSI(y,K=G,theta=theta,lambda=0,tol=1E-5)
 
 cor(y,fm1$u)        # G-BLUP accuracy
 cor(y,fitted(fm3))  # SSI accuracy
@@ -30,17 +34,19 @@ cor(y,fitted(fm3))  # SSI accuracy
 tst = seq(1,length(y),by=3)
 trn = (seq_along(y))[-tst]
 
-# Calculate heritability in training data
+# Calculate variance components in training data
 yNA = y
 yNA[tst] = NA
 fm1 = fitBLUP(yNA,K=G)
+(theta = fm1$varE/fm1$varU)
 (h2 = fm1$varU/(fm1$varU + fm1$varE))
 
 # Sparse selection index
-fm2 = SSI(y,K=G,h2=h2,trn=trn,tst=tst)
+fm2 = SSI(y,K=G,theta=theta,trn=trn,tst=tst)
 
-# Heritability internaly calculated
-fm2 = SSI(y,K=G,h2=NULL,trn=trn,tst=tst)
+# Variance components ratio internaly calculated
+fm2 = SSI(y,K=G,theta=NULL,trn=trn,tst=tst)
+fm2$theta
 fm2$h2
 
 # Effect of the penalization on the accuracy
